package com.lzmispt.data.resource.service.specialdatabase.impl;

package .tmp;

import com.lzmispt.core.entity.dto.authorize.UserInfoDTO;
import com.lzmispt.core.entity.vo.authorize.DataAuthorizeFunVO;
import com.lzmispt.core.entity.vo.authorize.DataAuthorizeItemFunInfoVO;
import com.lzmispt.core.entity.vo.authorize.GetDataAuthorizeInfoVO;
import com.lzmispt.data.center.entity.dto.log.CommonLogDTO;
import com.lzmispt.data.center.entity.dto.resource.metadata.GetDirectoryTreeDataDTO;
import com.lzmispt.data.center.entity.dto.standard.tag.UpdateTagMsg;
import com.lzmispt.data.center.entity.enums.StatusCodeEnum;
import com.lzmispt.data.center.entity.vo.resource.metadata.DirectoryTreeVO;
import com.lzmispt.data.center.entity.vo.specialdatabase.ResSpecialDatabasePurenessVO;
import com.lzmispt.data.resource.client.CoreClient;
import com.lzmispt.data.resource.client.DataStandardClient;
import com.lzmispt.data.resource.dao.specialdatabase.IResSpecialDatabaseDao;
import com.lzmispt.data.resource.entity.dto.metadata.MetadataDirectoryDTO;
import com.lzmispt.data.resource.entity.dto.specialdatabase.ResSpecialDatabaseDTO;
import com.lzmispt.data.resource.entity.dto.specialdatabase.SpecialDataBaseGetListBody;
import com.lzmispt.data.resource.entity.dto.specialdatabase.SpecialDataBaseListByAuthority;
import com.lzmispt.data.resource.entity.po.specialdatabase.ResDirectoryPO;
import com.lzmispt.data.resource.entity.po.specialdatabase.ResSpecialDatabasePO;
import com.lzmispt.data.resource.entity.vo.specialdatabase.ResSpecialDatabaseAuthVO;
import com.lzmispt.data.resource.entity.vo.specialdatabase.ResSpecialDatabaseVO;
import com.lzmispt.data.resource.service.metadata.IApplyService;
import com.lzmispt.data.resource.service.metadata.IResAndDataResource;
import com.lzmispt.data.resource.service.specialdatabase.IResSpecialDatabase;
import com.lzmispt.dcbase.dcconst.DCConst;
import com.lzmispt.dcbase.util.HeaderInterceptor;
import com.lzmispt.framework.entity.entity.ResultEntity;
import com.lzmispt.framework.fconst.FrameConst;
import com.lzmispt.framework.utils.RabbitMQUtil;
import com.lzmispt.framework.utils.WorkerId;
import java.util.ArrayList;
import java.util.Comparator;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Objects;
import java.util.stream.Collectors;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;
import org.springframework.util.CollectionUtils;
import org.springframework.util.StringUtils;

@Service
public class ResSpecialDatabaseImpl implements IResSpecialDatabase {
  @Autowired
  private IResSpecialDatabaseDao resSpecialDatabaseDao;
  
  @Value("${data-center.data-authority.apply:default}")
  private String applyDataAuthority;
  
  @Autowired
  private CoreClient coreInterfaceClient;
  
  @Autowired
  private DataStandardClient dataStandardClient;
  
  @Autowired
  private IApplyService applyService;
  
  public static final String THEMATIC_LIBRARY = "专题库_";
  
  @Autowired
  IResAndDataResource iResAndDataResource;
  
  public ResultEntity addResSpecialDatabase(ResSpecialDatabaseDTO specialdatabaseDTO, UserInfoDTO userInfoDTO) {
    ResSpecialDatabasePO specialdatabasePO = new ResSpecialDatabasePO();
    specialdatabasePO.setSpecialDatabaseName(specialdatabaseDTO.getSpecialDatabaseName());
    List<ResSpecialDatabasePO> resSpecialDatabaseList = getResSpecialDatabaseListNoLike(userInfoDTO, specialdatabasePO);
    if (!CollectionUtils.isEmpty(resSpecialDatabaseList))
      return ResultEntity.errorMessage(Integer.valueOf(StatusCodeEnum.DATA_RESOURCE_SPECIALDATABASE_INSERT_NAME_ERROR.getCode()), StatusCodeEnum.DATA_RESOURCE_SPECIALDATABASE_INSERT_NAME_ERROR.getMessage()); 
    Long key = (Long)WorkerId.getNextId(Long.class);
    ResSpecialDatabasePO dcSpecialdatabasePO = new ResSpecialDatabasePO();
    dcSpecialdatabasePO.setSpecialDatabaseName(specialdatabaseDTO.getSpecialDatabaseName());
    dcSpecialdatabasePO.setDescription(specialdatabaseDTO.getDescription());
    dcSpecialdatabasePO.setApplyId(specialdatabaseDTO.getApplyId());
    dcSpecialdatabasePO.setSpecialDatabaseId(key);
    dcSpecialdatabasePO.setUserIdRecord(userInfoDTO.getUserId());
    dcSpecialdatabasePO.setIsDelete(DCConst.FALSE.intValue());
    dcSpecialdatabasePO.setCreateTime(new Date());
    dcSpecialdatabasePO.setUpdateTime(new Date());
    dcSpecialdatabasePO.setOrgIdRecord(userInfoDTO.getOrganizationId());
    int orderMax = this.resSpecialDatabaseDao.getOrderMax() + 1;
    dcSpecialdatabasePO.setOrder(orderMax);
    int count = this.resSpecialDatabaseDao.insert(dcSpecialdatabasePO);
    if (count != 0) {
      ResSpecialDatabasePO resSpecialDatabasePO = this.resSpecialDatabaseDao.selectByPrimaryKey(key);
      ResSpecialDatabaseVO databaseVO = new ResSpecialDatabaseVO();
      getDcResSpecialDatabaseVO(resSpecialDatabasePO, databaseVO);
      databaseVO.setUpdateAuthority(Integer.valueOf(1));
      databaseVO.setDeleteAuthority(Integer.valueOf(1));
      MetadataDirectoryDTO metadataDirectoryDTO = new MetadataDirectoryDTO();
      metadataDirectoryDTO.setDirectoryName("资源应用库");
      metadataDirectoryDTO.setDirectoryType(Integer.valueOf(0));
      metadataDirectoryDTO.setSpecialDatabaseId(databaseVO.getSpecialDatabaseId());
      metadataDirectoryDTO.setDataCategory(DCConst.DataResourceCategory.RES);
      metadataDirectoryDTO.setDirectoryOrder(Integer.valueOf(1));
      metadataDirectoryDTO.setDirectoryCode("资源应用库");
      this.iResAndDataResource.saveMetadataDirectoryForResources(metadataDirectoryDTO, userInfoDTO.getTokenId(), "Apply");
      return ResultEntity.successMessage(databaseVO);
    } 
    return ResultEntity.errorMessage(Integer.valueOf(StatusCodeEnum.DATA_STANDARD_SPECIALDATABASE_INSERT_DATA_ERROR.getCode()), StatusCodeEnum.DATA_STANDARD_SPECIALDATABASE_INSERT_DATA_ERROR.getMessage());
  }
  
  private List<ResSpecialDatabasePO> getResSpecialDatabaseListNoLike(UserInfoDTO userInfoDTO, ResSpecialDatabasePO specialdatabasePO) {
    List<ResSpecialDatabasePO> specialDataBaseInfoList = new ArrayList<>();
    String dataAuthority = this.applyDataAuthority;
    switch (dataAuthority) {
      case "default":
        specialDataBaseInfoList = this.resSpecialDatabaseDao.selectResSpecialDatabaseAllNoLike(specialdatabasePO);
        break;
      case "userorg":
        specialdatabasePO.setOrgIdRecord(userInfoDTO.getOrganizationId());
        specialdatabasePO.setUserIdRecord(userInfoDTO.getUserId());
        specialDataBaseInfoList = this.resSpecialDatabaseDao.selectResSpecialDatabaseAllByUserAndOrgNoLike(specialdatabasePO);
        break;
      case "org":
        specialdatabasePO.setOrgIdRecord(userInfoDTO.getOrganizationId());
        specialDataBaseInfoList = this.resSpecialDatabaseDao.selectResSpecialDatabaseAllByOrgNoLike(specialdatabasePO);
        break;
    } 
    return specialDataBaseInfoList;
  }
  
  private ResSpecialDatabaseVO getDcResSpecialDatabaseVO(ResSpecialDatabasePO resSpecialDatabasePO, ResSpecialDatabaseVO databaseVO) {
    BeanUtils.copyProperties(resSpecialDatabasePO, databaseVO);
    return databaseVO;
  }
  
  public ResultEntity deleteResSpecialDatabaseByPrimaryKey(long primaryKey) {
    List<ResDirectoryPO> resDirectoryList = this.resSpecialDatabaseDao.selectDirectoryBySpecialDatabaseId(primaryKey);
    if (!CollectionUtils.isEmpty(resDirectoryList) && resDirectoryList.size() > 1)
      return ResultEntity.errorMessage(Integer.valueOf(StatusCodeEnum.DATA_RESOURCE_GET_DELETE_SPECIAL_DATABASE.getCode()), StatusCodeEnum.DATA_RESOURCE_GET_DELETE_SPECIAL_DATABASE.getMessage()); 
    ResSpecialDatabasePO resSpecialDatabasePO = this.resSpecialDatabaseDao.selectByPrimaryKey(Long.valueOf(primaryKey));
    if (resSpecialDatabasePO == null)
      return ResultEntity.errorMessage(Integer.valueOf(StatusCodeEnum.DATA_STANDARD_SPECIALDATABASE_QUERY_DATA_ERROR.getCode()), StatusCodeEnum.DATA_STANDARD_SPECIALDATABASE_QUERY_DATA_ERROR.getMessage()); 
    ResSpecialDatabasePO dcSpecialdatabasePO = new ResSpecialDatabasePO();
    dcSpecialdatabasePO.setSpecialDatabaseId(Long.valueOf(primaryKey));
    dcSpecialdatabasePO.setIsDelete(DCConst.TRUE.intValue());
    int count = this.resSpecialDatabaseDao.updateByPrimaryKeySelective(dcSpecialdatabasePO);
    if (count != 0)
      return ResultEntity.successMessage(Boolean.valueOf(true)); 
    return ResultEntity.errorMessage(Integer.valueOf(StatusCodeEnum.DATA_STANDARD_SPECIALDATABASE_DELETE_DATA_ERROR.getCode()), StatusCodeEnum.DATA_STANDARD_SPECIALDATABASE_DELETE_DATA_ERROR.getMessage());
  }
  
  public ResultEntity updateResSpecialDatabase(ResSpecialDatabaseDTO dcSpecialdatabaseDTO, UserInfoDTO userInfoDTO) {
    ResSpecialDatabasePO dcSpecialdatabasePO = new ResSpecialDatabasePO();
    dcSpecialdatabasePO.setSpecialDatabaseName(dcSpecialdatabaseDTO.getSpecialDatabaseName());
    dcSpecialdatabasePO.setSpecialDatabaseId(dcSpecialdatabaseDTO.getSpecialDatabaseId());
    dcSpecialdatabasePO.setDescription(dcSpecialdatabaseDTO.getDescription());
    dcSpecialdatabasePO.setApplyId(dcSpecialdatabaseDTO.getApplyId());
    dcSpecialdatabasePO.setUpdateTime(new Date());
    List<ResSpecialDatabasePO> resSpecialDatabaseList = getResSpecialDatabaseListNoLike(userInfoDTO, dcSpecialdatabasePO);
    if (!CollectionUtils.isEmpty(resSpecialDatabaseList))
      return ResultEntity.errorMessage(Integer.valueOf(StatusCodeEnum.DATA_RESOURCE_SPECIALDATABASE_INSERT_NAME_ERROR.getCode()), StatusCodeEnum.DATA_RESOURCE_SPECIALDATABASE_INSERT_NAME_ERROR.getMessage()); 
    int count = this.resSpecialDatabaseDao.updateByPrimaryKeySelective(dcSpecialdatabasePO);
    if (count != 0) {
      ResSpecialDatabasePO resSpecialDatabasePO = this.resSpecialDatabaseDao.selectByPrimaryKey(dcSpecialdatabaseDTO.getSpecialDatabaseId());
      ResSpecialDatabaseVO databaseVO = new ResSpecialDatabaseVO();
      getDcResSpecialDatabaseVO(resSpecialDatabasePO, databaseVO);
      databaseVO.setUpdateAuthority(Integer.valueOf(1));
      databaseVO.setDeleteAuthority(Integer.valueOf(1));
      return ResultEntity.successMessage(databaseVO);
    } 
    UpdateTagMsg updateTagMsg = new UpdateTagMsg();
    updateTagMsg.setSpecialDatabaseId(dcSpecialdatabasePO.getSpecialDatabaseId());
    updateTagMsg.setSpecialDatabaseName(dcSpecialdatabasePO.getSpecialDatabaseName());
    RabbitMQUtil.publish("DC.Resource.updateResSpecialSataBaseName", updateTagMsg);
    return ResultEntity.errorMessage(Integer.valueOf(StatusCodeEnum.DATA_STANDARD_SPECIALDATABASE_UPDATE_DATA_ERROR.getCode()), StatusCodeEnum.DATA_STANDARD_SPECIALDATABASE_UPDATE_DATA_ERROR.getMessage());
  }
  
  public ResultEntity getResSpecialDatabase(SpecialDataBaseGetListBody body, UserInfoDTO userInfoDTO) {
    SpecialDataBaseListByAuthority resultDataBase = new SpecialDataBaseListByAuthority();
    List<ResSpecialDatabaseVO> data = new ArrayList<>();
    ResSpecialDatabasePO specialdatabasePO = new ResSpecialDatabasePO();
    specialdatabasePO.setSpecialDatabaseName(body.getSearchFieldValue());
    List<ResSpecialDatabasePO> specialDataBaseInfoList = getResSpecialDatabaseList(userInfoDTO, specialdatabasePO);
    if (!CollectionUtils.isEmpty(specialDataBaseInfoList))
      for (ResSpecialDatabasePO resSpecialDatabasePO : specialDataBaseInfoList) {
        if (resSpecialDatabasePO.getUserIdRecord() != null && resSpecialDatabasePO.getUserIdRecord().equals(userInfoDTO.getUserId())) {
          resSpecialDatabasePO.setUpdateAuthority(DCConst.TRUE);
          resSpecialDatabasePO.setDeleteAuthority(DCConst.TRUE);
          addSpecialDataBase(resultDataBase, data, resSpecialDatabasePO);
        } 
      }  
    GetDataAuthorizeInfoVO getDataAuthorizeInfoVO = (GetDataAuthorizeInfoVO)this.coreInterfaceClient.getDataAuthorizeInfo(body.getGetDataAuthorizeInfoDTO(), userInfoDTO.getTokenId()).getObj();
    List<DataAuthorizeItemFunInfoVO> authorizeDataInfoList = getDataAuthorizeInfoVO.getAuthorizeDataInfoList();
    Map<String, List<DataAuthorizeItemFunInfoVO>> dataAuthorizeItemFunInfoVOMapper = (Map<String, List<DataAuthorizeItemFunInfoVO>>)authorizeDataInfoList.stream().collect(Collectors.groupingBy(DataAuthorizeItemFunInfoVO::getAuthItemId));
    for (Map.Entry<String, List<DataAuthorizeItemFunInfoVO>> stringListEntry : dataAuthorizeItemFunInfoVOMapper.entrySet()) {
      List<DataAuthorizeItemFunInfoVO> dataAuthorizeItemFunInfoVOList = stringListEntry.getValue();
      for (DataAuthorizeItemFunInfoVO dataAuthorizeItemFunInfoVO : dataAuthorizeItemFunInfoVOList) {
        List<DataAuthorizeFunVO> functions = dataAuthorizeItemFunInfoVO.getFunctions();
        for (DataAuthorizeFunVO function : functions) {
          if ("100000000000000000005".equals(stringListEntry.getKey()) && 
            function.getCode().equals("add"))
            resultDataBase.setAddAuthority(DCConst.TRUE); 
        } 
      } 
      for (ResSpecialDatabasePO resSpecialDatabasePO : specialDataBaseInfoList) {
        if (((String)stringListEntry.getKey()).equals(String.valueOf(resSpecialDatabasePO.getSpecialDatabaseId())) && !resSpecialDatabasePO.getUserIdRecord().equals(userInfoDTO.getUserId())) {
          boolean isResultData = false;
          boolean editAuthority = false;
          for (DataAuthorizeItemFunInfoVO dataAuthorizeItemFunInfoVO : dataAuthorizeItemFunInfoVOList) {
            List<DataAuthorizeFunVO> functions = dataAuthorizeItemFunInfoVO.getFunctions();
            for (DataAuthorizeFunVO function : functions) {
              if (function.getCode().equals("edit")) {
                resSpecialDatabasePO.setUpdateAuthority(DCConst.TRUE);
                editAuthority = true;
                isResultData = true;
              } 
              if (function.getCode().equals("delete")) {
                resSpecialDatabasePO.setDeleteAuthority(DCConst.TRUE);
                isResultData = true;
              } 
              if (function.getCode().equals("read_only")) {
                if (!editAuthority)
                  resSpecialDatabasePO.setUpdateAuthority(DCConst.FALSE); 
                isResultData = true;
              } 
            } 
          } 
          if (isResultData)
            addSpecialDataBase(resultDataBase, data, resSpecialDatabasePO); 
        } 
      } 
    } 
    if (!CollectionUtils.isEmpty(data))
      data = (List<ResSpecialDatabaseVO>)data.stream().sorted(Comparator.comparing(ResSpecialDatabaseVO::getOrder)).collect(Collectors.toList()); 
    resultDataBase.setAddAuthority(Integer.valueOf(StringUtils.isEmpty(resultDataBase.getAddAuthority()) ? 0 : 1));
    resultDataBase.setData(data);
    return ResultEntity.successMessage(resultDataBase);
  }
  
  private static void addSpecialDataBase(SpecialDataBaseListByAuthority resultDataBase, List<ResSpecialDatabaseVO> data, ResSpecialDatabasePO resSpecialDatabasePO) {
    ResSpecialDatabaseVO resSpecialDatabaseVO = new ResSpecialDatabaseVO();
    BeanUtils.copyProperties(resSpecialDatabasePO, resSpecialDatabaseVO);
    resSpecialDatabaseVO.setUpdateAuthority(Integer.valueOf(StringUtils.isEmpty(resSpecialDatabasePO.getUpdateAuthority()) ? 0 : resSpecialDatabasePO.getUpdateAuthority().intValue()));
    resSpecialDatabaseVO.setDeleteAuthority(Integer.valueOf(StringUtils.isEmpty(resSpecialDatabasePO.getDeleteAuthority()) ? 0 : resSpecialDatabasePO.getDeleteAuthority().intValue()));
    data.add(resSpecialDatabaseVO);
  }
  
  private List<ResSpecialDatabasePO> getResSpecialDatabaseList(UserInfoDTO userInfoDTO, ResSpecialDatabasePO specialdatabasePO) {
    List<ResSpecialDatabasePO> specialDataBaseInfoList = new ArrayList<>();
    String dataAuthority = this.applyDataAuthority;
    switch (dataAuthority) {
      case "default":
        specialDataBaseInfoList = this.resSpecialDatabaseDao.selectResSpecialDatabaseAll(specialdatabasePO);
        break;
      case "userorg":
        specialdatabasePO.setOrgIdRecord(userInfoDTO.getOrganizationId());
        specialdatabasePO.setUserIdRecord(userInfoDTO.getUserId());
        specialDataBaseInfoList = this.resSpecialDatabaseDao.selectResSpecialDatabaseAllByUserAndOrg(specialdatabasePO);
        break;
      case "org":
        specialdatabasePO.setOrgIdRecord(userInfoDTO.getOrganizationId());
        specialDataBaseInfoList = this.resSpecialDatabaseDao.selectResSpecialDatabaseAllByOrg(specialdatabasePO);
        break;
    } 
    return specialDataBaseInfoList;
  }
  
  private void logSystemInfo(String msg, String platCode, String tokenId) {
    CommonLogDTO logDTO = new CommonLogDTO();
    logDTO.setPlatCode(platCode);
    logDTO.setTokenId(tokenId);
    logDTO.setLoggerInformation(msg);
    logDTO.setLogLevel(FrameConst.Log.LOG_LEVEL_SYSTEM);
    logDTO.setLogType(0);
    logDTO.setModule_code(HeaderInterceptor.getModuleCode());
    RabbitMQUtil.publish("DC.Standard.log", logDTO);
  }
  
  private void logSystemError(String msg, String tokenId, String platCode) {
    CommonLogDTO logDTO = new CommonLogDTO();
    logDTO.setPlatCode(platCode);
    logDTO.setTokenId(tokenId);
    logDTO.setLoggerInformation(msg);
    logDTO.setLogLevel(FrameConst.Log.LOG_LEVEL_ERROR);
    logDTO.setLogType(0);
    RabbitMQUtil.publish("DC.Standard.log", logDTO);
  }
  
  public ResultEntity getResSpecialDatabaseAuthData(Map<String, Map<String, String>> params) {
    Map<String, String> queryParams = params.get("query");
    List<ResSpecialDatabaseAuthVO> resList = new ArrayList<>();
    ResSpecialDatabaseAuthVO res = new ResSpecialDatabaseAuthVO();
    res.setId("100000000000000000005");
    res.setName("资源专题库");
    res.setParent_id(null);
    res.setIs_match_query(Integer.valueOf(0));
    res.setType(Integer.valueOf(0));
    res.setChildren(new ArrayList());
    List<ResSpecialDatabaseAuthVO> resSpecialDatabaseList = this.resSpecialDatabaseDao.getResSpecialDatabaseAuthData(queryParams);
    if (resSpecialDatabaseList != null) {
      res.setChildren(resSpecialDatabaseList);
      resList.add(res);
      return ResultEntity.successMessage(resList);
    } 
    return ResultEntity.errorMessage(Integer.valueOf(StatusCodeEnum.DATA_STANDARD_SPECIALDATABASE_GET_DATA_ERROR.getCode()), StatusCodeEnum.DATA_STANDARD_SPECIALDATABASE_GET_DATA_ERROR.getMessage());
  }
  
  public ResultEntity<ResSpecialDatabasePurenessVO> getSpecialDatabaseById(String primaryKey, UserInfoDTO userInfoDTO) {
    ResSpecialDatabasePurenessVO resSpecialDatabaseVO = new ResSpecialDatabasePurenessVO();
    ResSpecialDatabasePO specialdatabasePO = this.resSpecialDatabaseDao.selectResourceClassById(primaryKey);
    if (specialdatabasePO != null)
      BeanUtils.copyProperties(specialdatabasePO, resSpecialDatabaseVO); 
    return ResultEntity.successMessage(resSpecialDatabaseVO);
  }
  
  public ResultEntity getResourceClassById(String primaryKey, UserInfoDTO userInfoDTO) {
    ResSpecialDatabasePO specialdatabasePO = this.resSpecialDatabaseDao.selectResourceClassById(primaryKey);
    ResSpecialDatabasePurenessVO resSpecialDatabaseVO = new ResSpecialDatabasePurenessVO();
    if (specialdatabasePO != null)
      BeanUtils.copyProperties(specialdatabasePO, resSpecialDatabaseVO); 
    return ResultEntity.successMessage(resSpecialDatabaseVO);
  }
  
  public ResultEntity<Map<Long, ResSpecialDatabasePurenessVO>> getResSpecialDatabaseByEntityIds(List<String> entityIds, String platCode, String tokenId) {
    Map<Long, ResSpecialDatabasePurenessVO> resultMap = new HashMap<>();
    ResultEntity<Map<Long, String>> applyDirectoryIds = null;
    try {
      applyDirectoryIds = this.dataStandardClient.getApplyDirectoryIds(entityIds, platCode, tokenId);
    } catch (Exception e) {
      logSystemError("根据entityId获取目录id远程调用失败：参数：" + entityIds, tokenId, platCode);
    } 
    if (!applyDirectoryIds.getCode().equals(DCConst.FALSE) || StringUtils.isEmpty(applyDirectoryIds.getObj())) {
      logSystemError("根据实体id获取目录id失败,值：" + applyDirectoryIds, platCode, tokenId);
      return ResultEntity.errorMessage(Integer.valueOf(StatusCodeEnum.DATA_RESOURCE_GET_DIRECTORY_ERROR.getCode()), StatusCodeEnum.DATA_RESOURCE_GET_DIRECTORY_ERROR.getMessage());
    } 
    Map<Long, String> entityMap = (Map<Long, String>)applyDirectoryIds.getObj();
    for (Long entityId : entityMap.keySet()) {
      String directoryId = entityMap.get(entityId);
      if (!StringUtils.isEmpty(directoryId)) {
        ResDirectoryPO resDirectoryPO = this.resSpecialDatabaseDao.selectResDirectoryById(directoryId);
        if (resDirectoryPO == null || StringUtils.isEmpty(resDirectoryPO.getSpecialDatabaseId()))
          return ResultEntity.errorMessage(Integer.valueOf(StatusCodeEnum.DATA_RESOURCE_GET_SPECIALDATABASE_ID_ERROR.getCode()), StatusCodeEnum.DATA_RESOURCE_GET_SPECIALDATABASE_ID_ERROR.getMessage()); 
        ResSpecialDatabasePO specialdatabasePO = this.resSpecialDatabaseDao.selectByPrimaryKey(resDirectoryPO.getSpecialDatabaseId());
        ResSpecialDatabasePurenessVO resSpecialDatabaseVO = new ResSpecialDatabasePurenessVO();
        BeanUtils.copyProperties(specialdatabasePO, resSpecialDatabaseVO);
        resultMap.put(entityId, resSpecialDatabaseVO);
        continue;
      } 
      resultMap.put(entityId, null);
    } 
    return ResultEntity.successMessage(resultMap);
  }
  
  public ResultEntity<List<ResSpecialDatabasePurenessVO>> getResSpecialDatabaseAll() {
    List<ResSpecialDatabasePurenessVO> result = new ArrayList<>();
    ResSpecialDatabasePO tempResSpecialDatabasePO = new ResSpecialDatabasePO();
    List<ResSpecialDatabasePO> resSpecialDatabasePOS = this.resSpecialDatabaseDao.selectResSpecialDatabaseAll(tempResSpecialDatabasePO);
    if (!CollectionUtils.isEmpty(resSpecialDatabasePOS))
      for (ResSpecialDatabasePO resSpecialDatabasePO : resSpecialDatabasePOS) {
        ResSpecialDatabasePurenessVO tempResSpecialDatabasePurenessVO = new ResSpecialDatabasePurenessVO();
        BeanUtils.copyProperties(resSpecialDatabasePO, tempResSpecialDatabasePurenessVO);
        result.add(tempResSpecialDatabasePurenessVO);
      }  
    return ResultEntity.successMessage(result);
  }
  
  public ResultEntity getDirectoryTreeDataForGIS(String platCode, GetDirectoryTreeDataDTO getDirectoryTreeDataDTO) {
    if (Objects.equals(getDirectoryTreeDataDTO.getIsLazyLoading(), DCConst.TRUE))
      return getListResultEntity(getDirectoryTreeDataDTO); 
    getDirectoryTreeDataDTO.setPlatCode("Apply");
    ResultEntity<Map> directoryTreeTableForRes = this.applyService.getDirectoryTreeTableForRes(getDirectoryTreeDataDTO, platCode);
    return ResultEntity.successMessage(((Map)directoryTreeTableForRes.getObj()).get("directoryTreeList"));
  }
  
  private ResultEntity<List<DirectoryTreeVO>> getListResultEntity(GetDirectoryTreeDataDTO getDirectoryTreeDataDTO) {
    if (getDirectoryTreeDataDTO.getSpecialDatabaseId() == null) {
      List<ResSpecialDatabasePurenessVO> databasePurenessList = (List<ResSpecialDatabasePurenessVO>)getResSpecialDatabaseAll().getObj();
      if (CollectionUtils.isEmpty(databasePurenessList))
        return ResultEntity.successMessage(new ArrayList()); 
      List<DirectoryTreeVO> voList = new ArrayList<>();
      for (ResSpecialDatabasePurenessVO resSpecialDatabasePO : databasePurenessList) {
        DirectoryTreeVO directoryTree = new DirectoryTreeVO();
        directoryTree.setDirectoryName(resSpecialDatabasePO.getSpecialDatabaseName());
        directoryTree.setParentDirectoryId(null);
        directoryTree.setDirectoryId(resSpecialDatabasePO.getSpecialDatabaseId());
        directoryTree.setSpecialDatabaseId(resSpecialDatabasePO.getSpecialDatabaseId());
        voList.add(directoryTree);
      } 
      return ResultEntity.successMessage(voList);
    } 
    List<ResDirectoryPO> resDirectoryPOList = null;
    if (getDirectoryTreeDataDTO.getDirectoryId() == null && getDirectoryTreeDataDTO.getSpecialDatabaseId() != null) {
      resDirectoryPOList = this.resSpecialDatabaseDao.selectResDirectoryByParentId(null, getDirectoryTreeDataDTO.getSpecialDatabaseId());
    } else {
      resDirectoryPOList = this.resSpecialDatabaseDao.selectResDirectoryByParentId(getDirectoryTreeDataDTO.getDirectoryId(), getDirectoryTreeDataDTO.getSpecialDatabaseId());
    } 
    List<DirectoryTreeVO> directoryTreeVOS = assembleMetadataDirectoryVO(resDirectoryPOList);
    return ResultEntity.successMessage(directoryTreeVOS);
  }
  
  private List<DirectoryTreeVO> assembleMetadataDirectoryVO(List<ResDirectoryPO> resDirectoryPOList) {
    List<DirectoryTreeVO> voList = new ArrayList<>();
    for (ResDirectoryPO resDirectoryPO : resDirectoryPOList) {
      DirectoryTreeVO directoryTree = new DirectoryTreeVO();
      BeanUtils.copyProperties(resDirectoryPO, directoryTree);
      voList.add(directoryTree);
    } 
    return voList;
  }
}
